
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */


#if !defined (__EV_XREADER_VIEW_H_INSIDE__) && !defined (XREADER_COMPILATION)
#error "Only <xreader-view.h> can be included directly."
#endif

#ifndef EV_VIEW_TYPE_BUILTINS_H
#define EV_VIEW_TYPE_BUILTINS_H

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "/build/xreader/src/build/../xreader/libview/ev-document-model.h" */
GType ev_sizing_mode_get_type (void) G_GNUC_CONST;
#define EV_TYPE_SIZING_MODE (ev_sizing_mode_get_type ())

/* enumerations from "/build/xreader/src/build/../xreader/libview/ev-job-scheduler.h" */
GType ev_job_priority_get_type (void) G_GNUC_CONST;
#define EV_TYPE_JOB_PRIORITY (ev_job_priority_get_type ())

/* enumerations from "/build/xreader/src/build/../xreader/libview/ev-jobs.h" */
GType ev_job_run_mode_get_type (void) G_GNUC_CONST;
#define EV_TYPE_JOB_RUN_MODE (ev_job_run_mode_get_type ())
GType ev_job_page_data_flags_get_type (void) G_GNUC_CONST;
#define EV_TYPE_JOB_PAGE_DATA_FLAGS (ev_job_page_data_flags_get_type ())

/* enumerations from "/build/xreader/src/build/../xreader/libview/ev-view.h" */
GType ev_view_selection_mode_get_type (void) G_GNUC_CONST;
#define EV_TYPE_VIEW_SELECTION_MODE (ev_view_selection_mode_get_type ())
G_END_DECLS

#endif /* !EV_VIEW_TYPE_BUILTINS_H */

/* Generated data ends here */

